==> alicloud_impinteraction_sdk-1.8.6.tar.gz: android/src/main/java/com/aliyun/imp/flutter/sdk/alicloud_impinteraction_sdk/plugin/FPOfBaseLive.java <==
package com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.plugin;

import android.app.Activity;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.CallbackAdapter;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.NativeView;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.NativeViewFactory;
import com.aliyun.roompaas.base.util.Utils;
import com.aliyun.roompaas.live.LiveEvent;
import com.aliyun.roompaas.live.SampleLiveEventHandler;
import com.aliyun.roompaas.live.exposable.LiveService;
import com.aliyun.roompaas.live.exposable.event.LiveCommonEvent;

import java.lang.ref.Reference;
import java.lang.ref.WeakReference;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

public abstract class FPOfBaseLive extends FPOfBase {
    private LiveService liveService;

    private int nativeViewId = 0x123;
    @Nullable
    protected Reference<ViewGroup> containerRef;

    protected interface BaseLiveAPI {
        String getLiveId = "getLiveId";
        String getLiveDetail = "getLiveDetail";
    }

    protected void getLiveId(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        String id = getLiveInstanceId();
        if (TextUtils.isEmpty(id)) {
            takeGeneralErr(result, "instance id empty");
        } else {
            takeSuccess(result, id);
        }
    }

    protected void getLiveDetail(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        getLiveService().getLiveDetail(new CallbackAdapter<>(call, result));
    }

    protected String getLiveInstanceId() {
        return getLiveService().getInstanceId();
    }

    @Nullable
    protected ViewGroup ofContainer() {
        ViewGroup container;
        if ((container = Utils.getRef(containerRef)) != null) {
            return container;
        }

        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            return null;
        }

        NativeView nativeView = NativeViewFactory.ofNativeView(activity, nativeViewId, null);
        View view = nativeView.getView();
        if ((view instanceof ViewGroup)) {
            container = (ViewGroup) view;
            containerRef = new WeakReference<>(container);
            return container;
        }

        return null;
    }

    protected LiveService getLiveService() {
        if (liveService == null) {
            liveService = getRoomChannel().getPluginService(LiveService.class);
            liveService.addEventHandler(new SampleLiveEventHandler() {
                @Override
                public void onLiveStarted(LiveCommonEvent event) {
                    postEvent("liveStarted", event);
                }

                @Override
                public void onLiveStopped(LiveCommonEvent event) {
                    postEvent("liveStopped", event);
                }

                @Override
                public void onRenderStart() {
                    postEvent("liveFirstFrameRendered");
                }

                @Override
                public void onLoadingBegin() {
                    postEvent("liveLoadingStarted");
                }

                @Override
                public void onLoadingEnd() {
                    postEvent("liveLoadingStopped");
                }

                @Override
                public void onPusherEvent(LiveEvent event) {
                    switch (event) {
                        case PREVIEW_STARTED:
                            postEvent("livePreviewStarted");
                            break;
                        case PUSH_STARTED:
                            postEvent("livePushStarted");
                            break;
                        case PUSH_STOPPED:
                            postEvent("livePushStopped");
                            break;
                        case RECONNECT_START:
                            postEvent("liveReconnectStart");
                            break;
                        case RECONNECT_SUCCESS:
                            postEvent("liveReconnectSuccess");
                            break;
                        case RECONNECT_FAIL:
                            postEvent("liveReconnectFail");
                            break;
                    }
                }
            });
        }
        return liveService;
    }

    @Override
    public void destroy() {
        super.destroy();
        liveService = null;
        Utils.clear(containerRef);
    }
}

==> alicloud_impinteraction_sdk-1.8.15.tar.gz: android/src/main/java/com/aliyun/imp/flutter/sdk/alicloud_impinteraction_sdk/plugin/FPOfBaseLive.java <==
package com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.plugin;

import android.app.Activity;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.CallbackAdapter;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.NativeView;
import com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.NativeViewFactory;
import com.aliyun.roompaas.base.util.Utils;
import com.aliyun.roompaas.live.LiveEvent;
import com.aliyun.roompaas.live.SampleLiveEventHandler;
import com.aliyun.roompaas.live.exposable.LiveService;
import com.aliyun.roompaas.live.exposable.event.LiveCommonEvent;

import java.lang.ref.Reference;
import java.lang.ref.WeakReference;
import java.util.Objects;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

public abstract class FPOfBaseLive extends FPOfBase {
    private LiveService liveService;

    private int nativeViewId = 0x123;
    @Nullable
    protected Reference<ViewGroup> containerRef;

    protected interface BaseLiveAPI {
        String getLiveId = "getLiveId";
        String getLiveDetail = "getLiveDetail";
    }

    protected void getLiveId(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        String id = getLiveInstanceId();
        if (TextUtils.isEmpty(id)) {
            takeGeneralErr(result, "instance id empty");
        } else {
            takeSuccess(result, id);
        }
    }

    protected void getLiveDetail(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        getLiveService().getLiveDetail(new CallbackAdapter<>(call, result));
    }

    protected String getLiveInstanceId() {
        return getLiveService().getInstanceId();
    }

    @Nullable
    protected ViewGroup ofContainer() {
        ViewGroup container;
        if ((container = Utils.getRef(containerRef)) != null) {
            return container;
        }

        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            return null;
        }

        NativeView nativeView = NativeViewFactory.ofNativeView(activity, nativeViewId, null);
        View view = nativeView.getView();
        if ((view instanceof ViewGroup)) {
            container = (ViewGroup) view;
            containerRef = new WeakReference<>(container);
            return container;
        }

        return null;
    }

    protected LiveService getLiveService() {
        if (liveService == null || !Objects.equals(liveService, getRoomChannel().getPluginService(LiveService.class))) {
            liveService = getRoomChannel().getPluginService(LiveService.class);
            liveService.addEventHandler(new SampleLiveEventHandler() {
                @Override
                public void onLiveStarted(LiveCommonEvent event) {
                    postEvent("liveStarted", event);
                }

                @Override
                public void onLiveStopped(LiveCommonEvent event) {
                    postEvent("liveStopped", event);
                }

                @Override
                public void onRenderStart() {
                    postEvent("liveFirstFrameRendered");
                }

                @Override
                public void onLoadingBegin() {
                    postEvent("liveLoadingStarted");
                }

                @Override
                public void onLoadingEnd() {
                    postEvent("liveLoadingStopped");
                }

                @Override
                public void onPusherEvent(LiveEvent event) {
                    switch (event) {
                        case PREVIEW_STARTED:
                            postEvent("livePreviewStarted");
                            break;
                        case PUSH_STARTED:
                            postEvent("livePushStarted");
                            break;
                        case PUSH_STOPPED:
                            postEvent("livePushStopped");
                            break;
                        case RECONNECT_START:
                            postEvent("liveReconnectStart");
                            break;
                        case RECONNECT_SUCCESS:
                            postEvent("liveReconnectSuccess");
                            break;
                        case RECONNECT_FAIL:
                            postEvent("liveReconnectFail");
                            break;
                    }
                }
            });
        }
        return liveService;
    }

    @Override
    public void destroy() {
        super.destroy();
        liveService = null;
        Utils.clear(containerRef);
    }
}
